@@ -9,30 +9,40 @@ import radical.utils as ru
 #
 class Entity(object):
 
-    def __init__(self, _uid, _etype, _profile, _details):
+    def __init__(self, _uid, _profile, _details):
         """
         Args:
-            uid (:obj:str): an ID assumed to be unique in the scope of an RA
+            uid (`str`): an ID assumed to be unique in the scope of an RA
                 Session
-            etype (:obj:str): the type of the entity. This defines, amongst
-                others, what event model the session will assume to be valid for
-                this entity.
-            profile: .
-            details: .
+            profile: a list of profile events for this entity
+            details: a dictionary of complementary information on this entity
         """
 
-        assert(_uid)
-        assert(_profile)
+        assert _uid
+        assert _profile
 
         self._uid         = _uid
-        self._etype       = _etype
         self._details     = _details
+        self._etype       = self._details.get('etype')
         self._description = self._details.get('description', dict())
         self._cfg         = self._details.get('cfg',         dict())
         self._resources   = self._details.get('resources',   dict())
 
+        # if have no etype tree information, guess the etype from uid
+        if not self._etype:
+            self._etype = self._uid.split('.')[0]
+
         # FIXME: this should be sorted out on RP level
-        self._cfg['hostid'] = self._details['hostid']
+        self._cfg['hostid'] = self._details.get('hostid')
+
+        # entities for which we have no tree information are raptor tasks (they
+        # were created by the master and never saw the client side)
+        # FIXME: this should be sorted out on RP level
+        if not self._etype:
+            if not self._details and 'task' in self._uid:
+                self._etype = 'raptor.task'
+            else:
+                self._etype = 'unknown'
 
         self._states      = dict()
         self._events      = list()
@@ -163,8 +173,8 @@ class Entity(object):
     def _initialize(self, profile):
 
         # only call once
-        assert (not self._states)
-        assert (not self._events)
+        assert not self._states
+        assert not self._events
 
         if profile:
             self._t_start = sys.float_info.max
@@ -265,9 +275,9 @@ class Entity(object):
           # pprint.pprint(self.events)
 
         else:
-            assert(not state)
-            assert(not event)
-            assert(not time)
+            assert not state
+            assert not event
+            assert not time
 
             # make sure the ranges are collapsed (although they likely are
             # already...)
