@@ -4,13 +4,13 @@
 from .plot import get_plotsize, get_mplstyle, stack_transitions
 from .plot import get_pilot_series, get_plot_utilization, get_pilots_zeros
 from .plot import to_latex
-
+from .plot import tabulate_durations
 
 # ------------------------------------------------------------------------------
 #
 __all__ = ('get_plotsize', 'get_mplstyle', 'stack_transitions',
            'get_pilot_series', 'get_plot_utilization', 'get_pilots_zeros',
-           'to_latex')
+           'to_latex', 'tabulate_durations')
 
 
 # ------------------------------------------------------------------------------
